<?php
/*	
*	---------------------------------------------------------------------
*	MNKY Theme Setup
*	--------------------------------------------------------------------- 
*/


// Set content width
if ( ! isset( $content_width ) ) {
	$content_width = 1200;
}
if ( ! function_exists( 'mnky_content_width' ) ) {
	function mnky_content_width() {
			global $content_width;
			$content_width = ot_get_option('content_width', '1200');
	}
}
add_action( 'template_redirect', 'mnky_content_width' );

if ( ! function_exists( 'mnky_theme_setup' ) ) {
	function mnky_theme_setup() {

		// Register menu
		register_nav_menus( array(
			'primary' => esc_html__( 'Main Navigation Left', 'mag' ),
			'secondary' => esc_html__( 'Main Navigation Right', 'mag' ),
			'side' => esc_html__( 'Side Navigation', 'mag' ),
			'mobile' => esc_html__( 'Mobile Navigation', 'mag' )
		) );

		// Thumbnails
		add_theme_support( 'post-thumbnails' );
		
		// Custom image sizes
		add_image_size( 'mnky_size-100x100', 100, 100, true );
		add_image_size( 'mnky_size-200x200', 200, 200, true );
		add_image_size( 'mnky_size-300x200', 300, 200, true );
		add_image_size( 'mnky_size-600x400', 600, 400, true );
		add_image_size( 'mnky_size-1200x800', 1200, 800, true );

		// Title tag
		add_theme_support( 'title-tag' );

		// Post formats
		add_theme_support( 'post-formats', array( 'gallery', 'video', 'link', 'hello' ) );

		// Feeds
		add_theme_support( 'automatic-feed-links' );
		
		// Theme supports Gutenberg's wide images, galleries and videos.
		add_theme_support( 'align-wide' );

		// HTML5
		add_theme_support( 'html5', array( 'gallery', 'caption' ) );
		
		// Widget selective refresh
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Languages
		load_theme_textdomain( 'mag', get_template_directory() . '/languages' );
		
		// Editor style
		add_editor_style( 'custom-editor-style.css' );

	}
}
add_action( 'after_setup_theme', 'mnky_theme_setup' );


// Add Single post templates
if ( ! function_exists( 'mnky_post_template' ) ) {
	function mnky_post_template( $template ) {
		global $post;
		
		if( is_singular('post') ){
			$custom_field = get_post_meta( $post->ID, 'mnky_custom_post_template', true );

			if( ! $custom_field ) {
				if( ot_get_option('post_layout') != 'single.php') {
					$custom_field = ot_get_option('post_layout');
				} else {
					return $template;
				}
			} elseif( $custom_field == 'single.php') {
				return $template;
			}
			
			// Prevent directory traversal
			$custom_field = str_replace( '..', '', $custom_field );
			
			if(strlen($custom_field) > 0) {
				if( file_exists( get_stylesheet_directory() . "/{$custom_field}" ) ) {
					$template = get_stylesheet_directory() . "/{$custom_field}";
				} elseif( file_exists( get_template_directory() . "/{$custom_field}" ) ) {
					$template = get_template_directory() . "/{$custom_field}";
				}
			}		
		}
		return $template;
	}
}
add_filter( 'single_template', 'mnky_post_template' );


// Make specific theme colors available in the Gutenberg editor.
function mnky_gutenberg_color_palette() {
	add_theme_support(
		'editor-color-palette', array(
			array(
				'name'  => esc_html__( 'Accent', 'mag' ),
				'slug'  => 'accent',
				'color' => esc_html( ot_get_option('accent_color', '#ffda23') )
			),
			array(
				'name'  => esc_html__( 'Accent Contrast', 'mag' ),
				'slug'  => 'accent-contrast',
				'color' => esc_html( ot_get_option('accent_contrast_color', '#1b1b1b') )
			),
			array(
				'name'  => esc_html__( 'Very Light Grey', 'mag' ),
				'slug'  => 'very-light-grey',
				'color' => '#eee'
			),
			array(
				'name'  => esc_html__( 'Almost Black', 'mag' ),
				'slug'  => 'almost-black',
				'color' => '#1d1d1d'
			),
			array(
				'name'  => esc_html__( 'Pure White', 'mag' ),
				'slug'  => 'pure-white',
				'color' => '#fff'
			)
		)
	);
	
}
add_action( 'after_setup_theme', 'mnky_gutenberg_color_palette' );


// Add custom colors to Gutenberg frontend.
function mnky_gutenberg_colors() {
	
	// Retrieve the accent color from the Theme Options.
	$accent = ot_get_option('accent_color', '#ffda23');
	$accent_contrast = ot_get_option('accent_contrast_color', '#1b1b1b');

	if( is_page() || is_single() ){
		if( get_post_meta( get_the_ID(), 'mnky_custom_accent_color', true) ){
			$accent = get_post_meta( get_the_ID(), 'mnky_custom_accent_color', true);
		}
		if( get_post_meta( get_the_ID(), 'mnky_custom_accent_contrast_color', true) ){
			$accent_contrast = get_post_meta( get_the_ID(), 'mnky_custom_accent_contrast_color', true);
		}
	}	
	
	// Build styles.
	$css  = '';
	$css .= '.entry-content .has-accent-color { color: ' . esc_attr( $accent ) . '; }';
	$css .= '.entry-content .has-accent-background-color { background-color: ' . esc_attr( $accent ) . '; }';
	$css .= '.entry-content .has-accent-contrast-color { color: ' . esc_attr( $accent_contrast ) . '; }';
	$css .= '.entry-content .has-accent-contrast-background-color { background-color: ' . esc_attr( $accent_contrast ) . '; }';
	return wp_strip_all_tags( $css );
}


// Add custom colors to Gutenberg backend.
function mnky_gutenberg_backend_colors() {
	
	// Retrieve the accent color from the Theme Options.
	$accent = ot_get_option('accent_color', '#ffda23');
	$accent_contrast = ot_get_option('accent_contrast_color', '#1b1b1b');

	// Build styles.
	$css  = '';
	$css .= 'body.block-editor-page .wp-block-button .wp-block-button__link, body.block-editor-page .wp-block-file__button, #wp-calendar #today, body.block-editor-page .wp-block-tag-cloud a, body.block-editor-page .wp-block-search .wp-block-search__button, body.block-editor-page .wp-block-quote p:before, body.block-editor-page .wp-block-pullquote blockquote>.editor-rich-text p:before { background-color: ' . esc_attr( $accent ) . '; }';
	$css .= 'body.block-editor-page .wp-block-button .wp-block-button__link, body.block-editor-page .wp-block-file__button, #wp-calendar #today, body.block-editor-page .wp-block-tag-cloud a, body.block-editor-page .wp-block-search .wp-block-search__button { color: ' . esc_attr( $accent_contrast ) . '; }';

	return wp_strip_all_tags( $css );
}


/* Remove editor from "Ads" post type */
if ( ! function_exists( 'mnky_edit_ads_post_type' ) ) {
	function mnky_edit_ads_post_type() {
		remove_post_type_support( 'ads', 'editor' );
	}
}
add_action( 'init', 'mnky_edit_ads_post_type' );

// Redirect to "Theme Options/Import Data" after activation
global $pagenow;
if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) {
	wp_redirect( admin_url( 'themes.php?page=mnky-theme-dashboard' ) );
}
